import tinymce from 'vue-tinymce-editor';

//

var script = {
    name : 'DynamicForms',
    props : {
        hidden : {
            default : '',
        },
        values : {
            type : Object,
            default: function default$1(){
                return {
                    name : 'This is my name',
                    text : 'This is my Text',
                    editor : '<p>This is my HTML Editor Data</p>'
                }
            }
        },
        form : {
            type : Array,
            default: function default$2(){
                return [
                    {
                        name : 'Name',
                        placeholder : 'Please Write Your Name...',
                        class : 'form-control',
                        column : 'name',
                        type : 'text',
                        value : 'test',
                    },
                    {
                        name : 'Name Two',
                        placeholder : 'Please Write Your Name...',
                        class : 'form-control',
                        column : 'text',
                        type : 'textarea',
                        value : 'Text Area',
                    }, 
                    {
                        name : 'Name Three',
                        class : 'form-control',
                        column : 'editor',
                        type : 'editor',
                        value : 'Text Area',
                    } ]
            }
        },
        title : {
            type : String,
            default : 'Your Title'
        },
        button : {
            type : Object,
            default: function default$3(){
                return {
                    title : 'My Button',
                    class : 'btn btn-success btn-block'
                }
            }
        },
        theme : {
            type : String,
            default : 'dark',
        }
    },
    model: {
        prop: 'hidden',
        event: 'update'
    },
    components : {
        tinymce: tinymce,
    },
    data: function data(){
        return {
            formBack : [],
        }
    },
    created: function created(){
        this.formBack = this.values;
    },
    methods : {
        action: function action(){
            this.$emit('save' , this.formBack);
        }
    },
    computed : {

    },
    watch : {
        formBack : {
            handler: function handler(){
                this.$emit('update' , this.formBack);
            },
            deep : true,
        }
    }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    var options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    var hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            var originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            var existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

var isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return function (id, style) { return addStyle(id, style); };
}
var HEAD;
var styles = {};
function addStyle(id, css) {
    var group = isOldIE ? css.media || 'default' : id;
    var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        var code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                { style.element.setAttribute('media', css.media); }
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            var index = style.ids.size - 1;
            var textNode = document.createTextNode(code);
            var nodes = style.element.childNodes;
            if (nodes[index])
                { style.element.removeChild(nodes[index]); }
            if (nodes.length)
                { style.element.insertBefore(textNode, nodes[index]); }
            else
                { style.element.appendChild(textNode); }
        }
    }
}

/* script */
var __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { attrs: { id: "addComponent" } }, [
    _c(
      "div",
      {
        class:
          "card " +
          (_vm.theme == "dark" ? "text-white bg-dark" : "text-black bg-white")
      },
      [
        _c("div", {
          staticClass: "card-header",
          domProps: { innerHTML: _vm._s(_vm.title) }
        }),
        _vm._v(" "),
        _c("div", { staticClass: "card-body" }, [
          _c(
            "form",
            {
              on: {
                submit: function($event) {
                  $event.preventDefault();
                  return _vm.action()
                }
              }
            },
            [
              _vm._l(_vm.form, function(f) {
                return _c("div", { key: f.name, staticClass: "form-group" }, [
                  f.type != "editor"
                    ? _c("div", { staticClass: "row" }, [
                        _c("div", { staticClass: "col-md-3" }, [
                          _c("label", { attrs: { for: f.column } }, [
                            _vm._v(_vm._s(f.name))
                          ])
                        ]),
                        _vm._v(" "),
                        _c("div", { staticClass: "col-md-9" }, [
                          f.type === "checkbox" &&
                          f.type != "selectbox" &&
                            f.type != "textarea" &&
                            f.type != "editor"
                            ? _c("input", {
                                directives: [
                                  {
                                    name: "model",
                                    rawName: "v-model",
                                    value: _vm.formBack[f.column],
                                    expression: "formBack[f.column]"
                                  }
                                ],
                                class: f.class,
                                attrs: {
                                  required: f.required ? "" : false,
                                  placeholder: f.placeholder,
                                  id: f.column,
                                  type: "checkbox"
                                },
                                domProps: {
                                  checked: Array.isArray(_vm.formBack[f.column])
                                    ? _vm._i(_vm.formBack[f.column], null) > -1
                                    : _vm.formBack[f.column]
                                },
                                on: {
                                  change: function($event) {
                                    var $$a = _vm.formBack[f.column],
                                      $$el = $event.target,
                                      $$c = $$el.checked ? true : false;
                                    if (Array.isArray($$a)) {
                                      var $$v = null,
                                        $$i = _vm._i($$a, $$v);
                                      if ($$el.checked) {
                                        $$i < 0 &&
                                          _vm.$set(
                                            _vm.formBack,
                                            f.column,
                                            $$a.concat([$$v])
                                          );
                                      } else {
                                        $$i > -1 &&
                                          _vm.$set(
                                            _vm.formBack,
                                            f.column,
                                            $$a
                                              .slice(0, $$i)
                                              .concat($$a.slice($$i + 1))
                                          );
                                      }
                                    } else {
                                      _vm.$set(_vm.formBack, f.column, $$c);
                                    }
                                  }
                                }
                              })
                            : f.type === "radio" &&
                              f.type != "selectbox" &&
                                f.type != "textarea" &&
                                f.type != "editor"
                            ? _c("input", {
                                directives: [
                                  {
                                    name: "model",
                                    rawName: "v-model",
                                    value: _vm.formBack[f.column],
                                    expression: "formBack[f.column]"
                                  }
                                ],
                                class: f.class,
                                attrs: {
                                  required: f.required ? "" : false,
                                  placeholder: f.placeholder,
                                  id: f.column,
                                  type: "radio"
                                },
                                domProps: {
                                  checked: _vm._q(_vm.formBack[f.column], null)
                                },
                                on: {
                                  change: function($event) {
                                    return _vm.$set(
                                      _vm.formBack,
                                      f.column,
                                      null
                                    )
                                  }
                                }
                              })
                            : f.type != "selectbox" &&
                              f.type != "textarea" &&
                              f.type != "editor"
                            ? _c("input", {
                                directives: [
                                  {
                                    name: "model",
                                    rawName: "v-model",
                                    value: _vm.formBack[f.column],
                                    expression: "formBack[f.column]"
                                  }
                                ],
                                class: f.class,
                                attrs: {
                                  required: f.required ? "" : false,
                                  placeholder: f.placeholder,
                                  id: f.column,
                                  type: f.type
                                },
                                domProps: { value: _vm.formBack[f.column] },
                                on: {
                                  input: function($event) {
                                    if ($event.target.composing) {
                                      return
                                    }
                                    _vm.$set(
                                      _vm.formBack,
                                      f.column,
                                      $event.target.value
                                    );
                                  }
                                }
                              })
                            : f.type == "textarea"
                            ? _c("textarea", {
                                directives: [
                                  {
                                    name: "model",
                                    rawName: "v-model",
                                    value: _vm.formBack[f.column],
                                    expression: "formBack[f.column]"
                                  }
                                ],
                                class: f.class,
                                attrs: {
                                  required: f.required ? "" : false,
                                  placeholder: f.placeholder,
                                  id: f.column
                                },
                                domProps: { value: _vm.formBack[f.column] },
                                on: {
                                  input: function($event) {
                                    if ($event.target.composing) {
                                      return
                                    }
                                    _vm.$set(
                                      _vm.formBack,
                                      f.column,
                                      $event.target.value
                                    );
                                  }
                                }
                              })
                            : _c(
                                "select",
                                {
                                  directives: [
                                    {
                                      name: "model",
                                      rawName: "v-model",
                                      value: _vm.formBack[f.column],
                                      expression: "formBack[f.column]"
                                    }
                                  ],
                                  class: f.class,
                                  attrs: {
                                    type: f.type,
                                    required: f.required ? "" : false,
                                    id: f.column
                                  },
                                  on: {
                                    change: function($event) {
                                      var $$selectedVal = Array.prototype.filter
                                        .call($event.target.options, function(
                                          o
                                        ) {
                                          return o.selected
                                        })
                                        .map(function(o) {
                                          var val =
                                            "_value" in o ? o._value : o.value;
                                          return val
                                        });
                                      _vm.$set(
                                        _vm.formBack,
                                        f.column,
                                        $event.target.multiple
                                          ? $$selectedVal
                                          : $$selectedVal[0]
                                      );
                                    }
                                  }
                                },
                                _vm._l(f.items, function(v) {
                                  return _c(
                                    "option",
                                    {
                                      key: v[f.value],
                                      domProps: { value: v[f.value] }
                                    },
                                    [
                                      _vm._v(
                                        "\n                                    " +
                                          _vm._s(v[f.show]) +
                                          "\n                                "
                                      )
                                    ]
                                  )
                                }),
                                0
                              )
                        ])
                      ])
                    : _c(
                        "div",
                        [
                          _c("label", { attrs: { for: f.column } }, [
                            _vm._v(_vm._s(f.name))
                          ]),
                          _vm._v(" "),
                          _c("tinymce", {
                            staticClass: "tinymce",
                            attrs: { id: f.column },
                            model: {
                              value: _vm.formBack[f.column],
                              callback: function($$v) {
                                _vm.$set(_vm.formBack, f.column, $$v);
                              },
                              expression: "formBack[f.column]"
                            }
                          })
                        ],
                        1
                      )
                ])
              }),
              _vm._v(" "),
              _c("div", { staticClass: "form-group row mb-0" }, [
                _c("div", { staticClass: "col-md-6 offset-md-3" }, [
                  _c("button", {
                    class: _vm.button.class,
                    attrs: { type: "submit" },
                    domProps: { innerHTML: _vm._s(_vm.button.title) }
                  })
                ])
              ])
            ],
            2
          )
        ])
      ]
    )
  ])
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  var __vue_inject_styles__ = function (inject) {
    if (!inject) { return }
    inject("data-v-3d71d9e2_0", { source: "\n\n/*# sourceMappingURL=DynamicForms.vue.map */", map: {"version":3,"sources":["DynamicForms.vue"],"names":[],"mappings":";;AAEA,2CAA2C","file":"DynamicForms.vue","sourcesContent":["\n\n/*# sourceMappingURL=DynamicForms.vue.map */"]}, media: undefined });

  };
  /* scoped */
  var __vue_scope_id__ = "data-v-3d71d9e2";
  /* module identifier */
  var __vue_module_identifier__ = undefined;
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  var __vue_component__ = normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

// Import vue component

// Declare install function executed by Vue.use()
function install(Vue) {
	if (install.installed) { return; }
	install.installed = true;
	Vue.component('DynamicForms', __vue_component__);
}

// Create module definition for Vue.use()
var plugin = {
	install: install,
};

// Auto-install when vue is found (eg. in browser via <script> tag)
var GlobalVue = null;
if (typeof window !== 'undefined') {
	GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
	GlobalVue = global.Vue;
}
if (GlobalVue) {
	GlobalVue.use(plugin);
}

export default __vue_component__;
export { install };
